@@ -115,6 +115,8 @@ class ONTSWAP(Base):
     old_ont_expunge_datetime = Column(DateTime)
     new_db_record_created = Column(Boolean, default=False)
     new_db_record_created_datetime = Column(DateTime)
+    deleted_from_tr069 = Column(Boolean, default=False)
+    deleted_from_tr069_datetime = Column(DateTime)
     user = Column(String(length=256), nullable=False, comment='user who requested the swap')
     task_request_datetime = Column(DateTime)
     task_finish_datetime = Column(DateTime)
